[MOAB-dev] commit/MOAB: danwu: Updated NC writer unit test to write two more GCRM variables (wind and pressure). Now the writer fails to write cell variable pressure, which should be fixed later.

commits-noreply at bitbucket.org commits-noreply at bitbucket.org
Mon Jun 2 11:36:49 CDT 2014


1 new commit in MOAB:

https://bitbucket.org/fathomteam/moab/commits/057b76553049/
Changeset:   057b76553049
Branch:      master
User:        danwu
Date:        2014-06-02 18:36:36
Summary:     Updated NC writer unit test to write two more GCRM variables (wind and pressure). Now the writer fails to write cell variable pressure, which should be fixed later.

Affected #:  1 file

diff --git a/test/io/write_nc.cpp b/test/io/write_nc.cpp
index d59829d..15979c0 100644
--- a/test/io/write_nc.cpp
+++ b/test/io/write_nc.cpp
@@ -747,7 +747,8 @@ void test_mpas_check_vars()
   }
 }
 
 // Write vertex variable vorticity, edge variable u and cell veriable ke
 void test_gcrm_read_write_vars()
 {
   int procs = 1;
@@ -772,15 +773,15 @@ void test_gcrm_read_write_vars()
   ErrorCode rval = mb.create_meshset(MESHSET_SET, set);
   CHECK_ERR(rval);
 
-  // Read non-set variables vorticity (cells) and u (corners)
-  read_opts += ";VARIABLE=vorticity,u;DEBUG_IO=0";
+  // Read non-set variables u, wind, vorticity and pressure
+  read_opts += ";VARIABLE=u,wind,vorticity,pressure;DEBUG_IO=0";
   if (procs > 1)
     read_opts += ";PARALLEL_RESOLVE_SHARED_ENTS";
   rval = mb.load_file(example_gcrm, &set, read_opts.c_str());
   CHECK_ERR(rval);
 
-  // Write variables vorticity, u
-  std::string write_opts = ";;VARIABLE=vorticity,u;DEBUG_IO=0";
+  // Write variables u, wind, vorticity and pressure
+  std::string write_opts = ";;VARIABLE=u,wind,vorticity,pressure;DEBUG_IO=0";
 #ifdef USE_MPI
   // Use parallel options
   write_opts += ";PARALLEL=WRITE_PART";
@@ -747,7 +747,8 @@ void test_mpas_check_vars()
 }
 
-// Write vertex variable vorticity, edge variable u and cell veriable ke
+// Check vertex variable u, edge variable wind, cell variable vorticity (on layers),
+// and cell variable pressure (on interfaces)
 void test_gcrm_read_write_vars()
 {

Repository URL: https://bitbucket.org/fathomteam/moab/

--

This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.


More information about the moab-dev mailing list